==> borg-1.4.4.tar.gz: bin/src/utils/platform_version.dart <==
/*
 * MIT License
 *
 * Copyright (c) 2020 Alexei Sintotski
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

// ignore_for_file: public_member_api_docs

import 'dart:io';

import 'package:meta/meta.dart';
import 'package:path/path.dart' as path;

import 'run_system_command.dart';

String dartSdkVersion = _yamlParseable(Platform.version);

String flutterSdkVersion({@required String flutterSdkPath}) => _yamlParseable((runSystemCommand(
      command: '${path.joinAll([flutterSdkPath, 'bin', 'flutter'])} --version',
      workingDirectory: Directory.current,
      // ignore: avoid_as
    ).stdout as String)
        .trim()
        .replaceAll(RegExp(r'\(.*\) '), ''));

String _yamlParseable(String s) => s.replaceAll('"', '');

==> borg-2.0.0.tar.gz: bin/src/utils/platform_version.dart <==
/*
 * MIT License
 *
 * Copyright (c) 2020 Alexei Sintotski
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

// ignore_for_file: public_member_api_docs

import 'dart:io';

import 'package:path/path.dart' as path;

import 'run_system_command.dart';

String dartSdkVersion = _yamlParseable(Platform.version);

String flutterSdkVersion({required String flutterSdkPath}) => _yamlParseable(
      (runSystemCommand(
        command:
            '${path.joinAll([flutterSdkPath, 'bin', 'flutter'])} --version',
        workingDirectory: Directory.current,
        // ignore: avoid_as
      ).stdout as String)
          .trim()
          .replaceAll(RegExp(r'\(.*\) '), ''),
    );

String _yamlParseable(String s) => s.replaceAll('"', '');
